@@ -182,7 +182,12 @@ void MainWindow::closeEvent(QCloseEvent* closeEvent)
   {
     CallbackType cb = provider->logout();
     if ( cb == Callback_Sync )
+    {
+      // Save the settings when closing the program
+      d->accounts->saveSettings();
+
       QWidget::closeEvent(closeEvent);
+    }
     else
     {
       // Ignore the close event
@@ -203,6 +208,9 @@ void MainWindow::closeEvent(QCloseEvent* closeEvent)
   }
   else
   {
+    // Save the settings when closing the program
+    d->accounts->saveSettings();
+
     QWidget::closeEvent(closeEvent);
   }
 }
